//
//  Inspire.h
//  ac-analysis-ios-demo
//
//  Created by __zimu on 16/4/29.
//  Copyright © 2016年 ablecloud. All rights reserved.
//


#import <UIKit/UIKit.h>

//SDK版本
#define kVERSION @"1.0.3"

typedef NS_ENUM(NSInteger, ACProfileType) {
    ACProfileTypeUser       = 1,
    ACProfileTypeDevice     = 2,
    ACProfileTypePhone      = 3,
};

typedef NS_ENUM(NSUInteger, InspireMode) {
    //测试环境
    InspireModeTest,
    //正式环境
    InspireModeRouter,
};

typedef NS_ENUM(NSUInteger, InspireRegion) {
    //中国
    InspireRegionChina,
    //东南亚
    InspireRegionSouthEastAsia,
    //欧洲
    InspireRegionCentralEurope,
    //美洲
    InspireRegionNorthAmerica,
};

@class INSContext;
@interface Inspire : NSObject

///  配置开发环境
///
///  @param mode   开发环境
///  @param region 地区
+ (void)setMode:(InspireMode)mode Region:(InspireRegion)region;

///  配置开发者信息
///
///  @param majorDomain 主域
///  @param subDomain   子域
///  @param developerId 开发者id
///  @param accessKey   accessKey
///  @param secretyKey  secretyKey
+ (void)startWithMajorDomain:(NSString *)majorDomain
                   subDomain:(NSString *)subDomain
                 developerId:(NSString *)developerId
                   accessKey:(NSString *)accessKey
                  secretyKey:(NSString *)secretyKey;

///  设置当前用户的id, 支持`NSString` 和 `NSNumber`类型
+ (void)identify:(id)identifier;
+ (id)getIdentifier;

///  设置用户/设备的一个或多个Profile
///  Profile如果存在 则覆盖更新 否则 新创建
///
///  @param type        类型,表示用户表/设备表
///  @param id          唯一标识,如userId/deviceId
///  @param properties  用户/设备属性列表
+ (void)setProfile:(ACProfileType)type identifier:(NSString *)identifier properties:(NSDictionary *)properties;

///  追踪事件
+ (void)track:(NSString *)eventName;

///  追踪事件
///
///  @param eventName   事件名称
///  @param properties  自定义事件属性
+ (void)track:(NSString *)eventName properties:(NSDictionary *)properties;

#pragma mark - 上传事件
///  手动上传当前的事件
+ (void)flush;
///  设置自动上传数据时间间隔, 默认是60s
+ (void)setFlushInterval:(NSInteger)flushInterval;

#pragma mark - 页面统计时长
/** 自动页面时长统计, 开始记录某个页面展示时长.
 使用方法：必须配对调用beginPageView:和endPageView:两个函数来完成自动统计，若只调用某一个函数不会生成有效数据。
 在该页面展示时调用beginPageView:，当退出该页面时调用endPageView:
 @param pageName 统计的页面名称.
 @return void.
 */
+ (void)beginPageView:(NSString *)pageName;

/** 自动页面时长统计, 结束记录某个页面展示时长.
 使用方法：必须配对调用beginPageView:和endPageView:两个函数来完成自动统计，若只调用某一个函数不会生成有效数据。
 在该页面展示时调用beginPageView:，当退出该页面时调用endPageView:
 @param pageName 统计的页面名称.
 @return void.
 */
+ (void)endPageView:(NSString *)pageName;


#pragma mark - 事件时长统计
/** 自定义事件时长统计, 开始记录某个自定义事件时长
 使用方法：必须配对调用beginLogPageView:和endLogPageView:两个函数来完成自动统计，Â若只调用某一个函数不会生成有效数据。
 在该页面展示时调用beginLogPageView:，当退出该页面时调用endLogPageView:
 @param pageName 统计的事件名称.
 @return void.
 */
+ (void)beginTrack:(NSString *)eventName;
/** 自定义事件时长统计, 结束记录某个自定义事件时长
 使用方法：必须配对调用beginTrack:和endTrack:两个函数来完成自动统计，Â若只调用某一个函数不会生成有效数据。
 在该页面展示时调用beginTrack:，当退出该页面时调用endTrack:
 @param pageName 统计的事件名称.
 @return void.
 */
+ (void)endTrack:(NSString *)eventName;



@end
